# ServiceForwarder

The ServiceForwarder provides a mechanism to expose a bind address, protocol and port on a connector, that will be forwarded to an ApplicationService found on another connector. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MetadataWithId**](MetadataWithId.md) |  | [optional] 
**spec** | [**ServiceForwarderSpec**](ServiceForwarderSpec.md) |  | 
**status** | [**ServiceForwarderStatus**](ServiceForwarderStatus.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


